@@ -262,6 +262,7 @@ colourise_cols <- function(cols, colourise = crayon::has_color()) {
 
       col_double = ,
       col_integer = ,
+      col_big_integer = ,
       col_number = crayon::green(cols[[i]]),
 
       col_date = ,
@@ -360,9 +361,13 @@ vroom_select <- function(x, col_select, id) {
   # reorder and rename columns
   if (inherits(col_select, "quosures") || !rlang::quo_is_null(col_select)) {
     if (inherits(col_select, "quosures")) {
-      vars <- tidyselect::vars_select(c(id, names(spec(x)$cols)), !!!col_select)
+      vars <- tidyselect::vars_select(c(names(spec(x)$cols), id), !!!col_select)
     } else {
-      vars <- tidyselect::vars_select(c(id, names(spec(x)$cols)), !!col_select)
+      vars <- tidyselect::vars_select(c(names(spec(x)$cols), id), !!col_select)
+    }
+    if (!is.null(id) && !id %in% vars) {
+      names(id) <- id
+      vars <- c(id, vars)
     }
     # This can't be just names(x) as we need to have skipped
     # names as well to pass to vars_select()
@@ -514,11 +519,15 @@ collector_value.collector_logical <- function(x, ...) { logical() }
 #' @export
 collector_value.collector_factor <- function(x, ...) { factor() }
 
+# the more obvious as.POSIXct(double()) doesn't work on R < 4.0
+# https://github.com/tidyverse/vroom/issues/453
 #' @export
-collector_value.collector_datetime <- function(x, ...) { as.POSIXct(double()) }
+collector_value.collector_datetime <- function(x, ...) { vctrs::vec_ptype(Sys.time()) }
 
+# the more obvious as.Date(double()) doesn't work on R < 4.0
+# and again: https://github.com/tidyverse/vroom/issues/453
 #' @export
-collector_value.collector_date <- function(x, ...) { as.Date(double()) }
+collector_value.collector_date <- function(x, ...) { vctrs::vec_ptype(Sys.Date()) }
 
 #' @export
 collector_value.collector_time <- function(x, ...) { hms::hms() }
@@ -535,7 +544,7 @@ summary.col_spec <- function(object, width = getOption("width"), locale = defaul
   }
 
   type_map <- c("collector_character" = "chr", "collector_double" = "dbl",
-    "collector_integer" = "int", "collector_num" = "num", "collector_logical" = "lgl",
+    "collector_integer" = "int", "collector_number" = "num", "collector_logical" = "lgl",
     "collector_factor" = "fct", "collector_datetime" = "dttm", "collector_date" = "date",
     "collector_time" = "time",
     "collector_guess" = "???")
